==> cms-db_v0.7.9.tar.gz: admin/new.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('pages');
include('locale.inc.php');
$locale = new LocalizingClass('pages');
?>
<?php
include('../functions_url.inc.php');

if (isset($_POST['FORM_NEW_SENT'])) {
	if (trim($_POST['name']) == '') {
		include('error.inc.php');
		throw_error(locale('desc_new-error-name',true), 'pages.php?'.SID);
	}
	if ($_POST['sec'] == 'root') {
		$dir = 'data/pages';
	} else {
		$shorturl = get_filename_from_url($_POST['sec']);
		if ($shorturl === false) {
			die('Error: The page couldn\'t be found in the URL index.');
		}
		$dir = 'data/pages'.substr($shorturl, 0, strrpos($shorturl, '/'));
	}
	$sec = '../'.$dir;
	$name = str_replace(" " ,"_", stripslashes($_POST['name']));
	$name = str_replace("&" ,"AND", $name);
	$name = str_replace("/" ,"SLASH", $name);
	mkdir('../'.$dir.'/'.$_POST['id'].','.$name);
	if (!copy('./newfile', $sec.'/'.$_POST['id'].','.$name.'/01,Home')) {
		include('error.inc.php');
		throw_error(locale('desc_new-error',true).' ('.$sec.'/'.$_POST['id'].','.$_POST['name'].'/01,Home)', 'pages.php?'.SID);
	}
	include('cache.inc.php');
	clear_cache('pages');
	include('urlindex.inc.php');
	generate_urlindex();
	read_urlindex('..');
	header('Location:editpage.php?file='.get_short_url(substr($sec.'/'.$_POST['id'].','.$name.'/01,Home', 13)).'&'.SID);
} else {
	function getID() {
	   if ($_GET['sec'] == 'root') {
	      $home_pfad = '../data/pages/';
	   } else {
	      $home_pfad = get_filename_from_url($_GET['sec']);
	      $home_pfad = '../data/pages'.substr($home_pfad, 0, strrpos($home_pfad, '/'));
	   }
	   $i = 1;

	   $dh = opendir($home_pfad);
	   while ($datei = readdir($dh)) {
		  if($datei !== ""   &&
			 $datei !== "."  &&
			 $datei !== "..") {
				$i++;
		  }
	   }
	   if ($i < 10) {
		  $i = '0'.$i;
	   }
	   return $i;
	}
	$id = getID();
	if ($id > 99) {
		include('error.inc.php');
		throw_error(locale('desc_new-error-count',true), 'pages.php?'.SID);
	}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_new') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h2><?php locale('title_new') ?></h2>
<p>
	<form action="new.php?<?php echo SID ?>" method="post">
		<input type="hidden" name="FORM_NEW_SENT" value="" />
		<input type="hidden" name="sec" value="<?php echo $_GET['sec'] ?>" />
		<input type="hidden" name="id" value="<?php echo $id ?>" />
		<?php echo $id ?>,<input type="text" name="name" /><br />
		<input type="submit" name="newsec" value="<?php locale('button_create') ?>">
	</form>
</p>

</body>
</html>
<?php
}
?>

==> cms-db_v0.8.1.tar.gz: admin/new.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('pages');
include('locale.inc.php');
$locale = new LocalizingClass('pages');
?>
<?php
include('../functions_url.inc.php');

if (isset($_POST['FORM_NEW_SENT'])) {
	include('escape.inc.php');
	if (trim($_POST['name']) == '') {
		include('error.inc.php');
		throw_error(locale('desc_new-error-name',true), 'pages.php?'.SID.csrf_protection_get());
	}
	if ($_POST['sec'] == 'root') {
		$dir = 'data/pages';
	} else {
		$shorturl = get_filename_from_url($_POST['sec']);
		if ($shorturl === false) {
			die('Error: The page couldn\'t be found in the URL index.');
		}
		$dir = 'data/pages'.substr($shorturl, 0, strrpos($shorturl, '/'));
	}
	$sec = '../'.$dir;
	$name = str_replace(" " ,"_", escapeSL($_POST['name']));
	$name = str_replace("&" ,"AND", $name);
	$name = str_replace("/" ,"SLASH", $name);
	mkdir('../'.$dir.'/'.$_POST['id'].','.$name);
	if (!copy('./newfile', $sec.'/'.$_POST['id'].','.$name.'/01,Home')) {
		include('error.inc.php');
		throw_error(locale('desc_new-error',true).' ('.$sec.'/'.$_POST['id'].','.$_POST['name'].'/01,Home)', 'pages.php?'.SID.csrf_protection_get());
	}
	include('cache.inc.php');
	clear_cache('pages');
	include('urlindex.inc.php');
	generate_urlindex();
	read_urlindex('..');
	header('Location:editpage.php?file='.get_short_url(substr($sec.'/'.$_POST['id'].','.$name.'/01,Home', 13)).'&'.SID.csrf_protection_get());
} else {
	function getID() {
	   if ($_GET['sec'] == 'root') {
	      $home_pfad = '../data/pages/';
	   } else {
	      $home_pfad = get_filename_from_url($_GET['sec']);
	      $home_pfad = '../data/pages'.substr($home_pfad, 0, strrpos($home_pfad, '/'));
	   }
	   $i = 1;

	   $dh = opendir($home_pfad);
	   while ($datei = readdir($dh)) {
		  if($datei !== ""   &&
			 $datei !== "."  &&
			 $datei !== "..") {
				$i++;
		  }
	   }
	   if ($i < 10) {
		  $i = '0'.$i;
	   }
	   return $i;
	}
	$id = getID();
	if ($id > 99) {
		include('error.inc.php');
		throw_error(locale('desc_new-error-count',true), 'pages.php?'.SID.csrf_protection_get());
	}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_new') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h2><?php locale('title_new') ?></h2>
<p>
	<form action="new.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
		<input type="hidden" name="FORM_NEW_SENT" value="" />
		<input type="hidden" name="sec" value="<?php echo $_GET['sec'] ?>" />
		<input type="hidden" name="id" value="<?php echo $id ?>" />
		<?php echo $id ?>,<input type="text" name="name" /><br />
		<input type="submit" name="newsec" value="<?php locale('button_create') ?>">
	</form>
</p>

</body>
</html>
<?php
}
?>
